diff --git a/suite/regress/x86_call5.py b/suite/regress/x86_call5.py
index 5e877de07f4a7ae5644094a43cd95471096354a8..f5cb2668b3f717790c7f0359c8843de9fef6b307 100755
--- a/suite/regress/x86_call5.py
+++ b/suite/regress/x86_call5.py
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
 # Test 'jmp 0' with both X86 Intel & ATT syntax
 
 # Github issue: #56
 # Author: Nguyen Anh Quynh
@@ -9,6 +9,16 @@ from keystone import *
 
 import regress
 
+class TestX86ATT(regress.RegressTest):
+    def runTest(self):
+        # Initialize Keystone engine
+        ks = Ks(KS_ARCH_X86, KS_MODE_32)
+        # Assemble to get back insn encoding & statement count
+        encoding, count = ks.asm(b"call 5", 0x2000)
+        # Assert the result
+        self.assertEqual(encoding, [ 0xe8, 0x00, 0xe0, 0xff, 0xff ])
+
+
 class TestX86Intel(regress.RegressTest):
     def runTest(self):
         # Initialize Keystone engine
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# Test 'jmp 0' with both X86 Intel & ATT syntax
+# Test 'call 5' with both X86 Intel & ATT syntax
 
 # Github issue: #56